@@ -12,8 +12,7 @@ from scipy import interpolate, optimize, special, integrate
 import matplotlib.pyplot as plt
 from matplotlib.transforms import Bbox
 
-from ..results import JettoResults, JsetEcrhParams
-
+from ..results import JettoResults, JsetEcrhParams, GrayFortFile
 
 class AnalysisError(Exception):
     pass
@@ -146,10 +145,13 @@ def plot_analysis_2( results: JettoResults, t1: float, beamname: Optional[str] =
 
     jsetselbeams=[params.beam for params in ecrh_params]
 
-    #graybeam inpuy
+    #graybeam input
     graybeams = results.load_graybeams()
     #graybeam central ray output
     all_gray_ray_coords = results.load_gray_central_ray_coord()
+    #graybeam individual beam jz, pd
+    all_gray_ray_jz_pd=GrayFortFile.load(str(results.root)+'/fort.648')
+    print(all_gray_ray_jz_pd[0].data)
 
     # nothing selected by the user, plot all beams, please don't change this
     if not beamname:
@@ -159,16 +161,18 @@ def plot_analysis_2( results: JettoResults, t1: float, beamname: Optional[str] =
 
     allbeamnames = [b.beamname for b in graybeams]
     gray_rays_coords = []
+    gray_rays_jz_pds = []
     for bn in beamname:
        ixgraybeam=allbeamnames.index(bn)
        ixgraybeamoutput=jsetselbeams.index(bn)
        gray_rays_coords.append(all_gray_ray_coords[ixgraybeamoutput])
+       gray_rays_jz_pds.append(all_gray_ray_jz_pd[ixgraybeamoutput])
        freq = graybeams[ixgraybeam].fghz * 1e9 #only last beam freq. is used. cannot plot amny beams freq.
 
     #print
     for ic, graybeam in zip(range(len(graybeams)),graybeams):
         print('gray beam # {:d}, {:s}, f = {:5.2f}GHz, launch R0, Z0 = {:5.2f}m, {:5.2f}m'.format(ic+1,graybeam.beamname,graybeam.fghz,graybeam.grid[0].x0/1000.,graybeam.grid[0].z0/1000.))
-
+    
     for gray_ray_coords in gray_rays_coords:
         #print
         print('gray beam traced launch R0, Z0 = {:5.2f}m, {:5.2f}m'.format(gray_ray_coords.data['R'][0],gray_ray_coords.data['z'][0]))
@@ -288,28 +292,31 @@ def plot_analysis_2( results: JettoResults, t1: float, beamname: Optional[str] =
     ), transform=ax4.transAxes, ha='right', va='center')
     ax4.set_xlabel('rhot')
     ax4.set_ylabel(f'Power density (${pref.symbol}W/m^3$)')
+    for gray_rays_jz_pd in gray_rays_jz_pds:
+        ax4.plot(gray_rays_jz_pd.data['rhot'],gray_rays_jz_pd.data['dPdV'],linestyle='',marker='.')
 
-    def gaus(x, a, x0, sigma):
-        return a * np.exp(-(x - x0) ** 2 / (2 * sigma ** 2))
-
-    guessmax = np.max(QECEp)
-    ixguessmax = np.argmin(np.abs(QECEp - guessmax))
-    guessposmax = XRHOp[ixguessmax]
-    popt, pcov = optimize.curve_fit(
-        gaus, XRHOp, QECEp,
-        p0=[guessmax, guessposmax, 0.1],
-    )
-    print('Gauss fit: rho_0={0:5.4f}, sigma={1:5.4f}'.format(popt[1], popt[2]))
-    x = np.linspace(0, 1, 101)
-    ax4.plot(x, pref.adjust(gaus(x, *popt)), ':', label='fit')
+    #Gauss fit - removed
+    #def gaus(x, a, x0, sigma):
+    #    return a * np.exp(-(x - x0) ** 2 / (2 * sigma ** 2))
+    #guessmax = np.max(QECEp)
+    #ixguessmax = np.argmin(np.abs(QECEp - guessmax))
+    #guessposmax = XRHOp[ixguessmax]
+    #popt, pcov = optimize.curve_fit(
+    #    gaus, XRHOp, QECEp,
+    #    p0=[guessmax, guessposmax, 0.1],
+    #)
+    #print('Gauss fit: rho_0={0:5.4f}, sigma={1:5.4f}'.format(popt[1], popt[2]))
+    #x = np.linspace(0, 1, 101)
+    #ax4.plot(x, pref.adjust(gaus(x, *popt)), ':', label='fit')
     ax4.legend()
 
-    print('CD eff at rho={0:5.4f}, eta={1:7.4e} A.m/W'.format(
-        XRHOp[ixguessmax],
-        JZECp[ixguessmax] / QECEp[ixguessmax]))
+    #print('CD eff at rho={0:5.4f}, eta={1:7.4e} A.m/W'.format(
+    #    XRHOp[ixguessmax],
+    #    JZECp[ixguessmax] / QECEp[ixguessmax]))
 
     # current
-    pref = MetricPrefix(np.max(JZECp))
+    #pref = MetricPrefix(np.max(JZECp))
+    pref = MetricPrefix(1e6)
     RIp0 = RIp[0]
     ec_cal = np.sum(JZECp * d_volume) / (2.0 * np.pi * RIp0)
 
@@ -321,6 +328,8 @@ def plot_analysis_2( results: JettoResults, t1: float, beamname: Optional[str] =
     ), transform=ax5.transAxes, ha='right', va='center')
     ax5.set_xlabel('rhot')
     ax5.set_ylabel(f'Current density (${pref.symbol}A/m^2)$')
+    for gray_rays_jz_pd in gray_rays_jz_pds:
+        ax5.plot(gray_rays_jz_pd.data['rhot'],gray_rays_jz_pd.data['Jphi'],linestyle='',marker='.')
     ax5.legend()
 
     #fig.tight_layout()
