@@ -419,10 +419,35 @@ def read_binary_file(input_path, output_file=None):
             traces[key] = trac_data
         data['Traces'] = traces
 
+    data = remove_duplicate_times(data, keep='last')
     data = standardize_data_representation(data, header_info, endianness)
     return data
 
 
+def remove_duplicate_times(data, keep='first'):
+    """ Removes duplicate time slices """
+    time_vector = None
+    if 'Traces' in data and 'PPF Base Vectors' in data and 'TVEC1' in data['PPF Base Vectors']:
+        time_vector = data['PPF Base Vectors']['TVEC1'].flatten()
+    if 'Profiles' in data and 'TIME' in data['Profiles']:
+        time_vector = data['Profiles']['TIME'].flatten()
+    if time_vector is not None:
+        full_length = len(time_vector)
+        unique_values, unique_indices = np.unique(time_vector, return_index=True)
+        if len(unique_indices) != full_length:
+            if keep == 'last':
+                index_diff = np.hstack((np.diff(unique_indices), 1)).astype(np.int64)
+                unique_indices = unique_indices + index_diff - 1
+            if 'Traces' in data:
+                data['PPF Base Vectors']['TVEC1'] = np.take(data['PPF Base Vectors']['TVEC1'], unique_indices, axis=0)
+                for key in data['Traces']:
+                    data['Traces'][key] = np.take(data['Traces'][key], unique_indices, axis=0)
+            if 'Profiles' in data:
+                for key in data['Profiles']:
+                    data['Profiles'][key] = np.take(data['Profiles'][key], unique_indices, axis=0)
+    return data
+
+
 def standardize_data_representation(data, header_info, endianness):
     """ Standardize field formats and labels """
     data['SECTIONS'] = [key for key in data.keys() if key != 'INFO']
