@@ -675,7 +675,7 @@ class RunConfig:
             if _is_gray_parameter(param):
                 continue
 
-            jset_ids  = jetto_tools.template.Template.extract_jset_ids(self._template.lookup[param])
+            jset_ids = jetto_tools.template.Template.extract_jset_ids(self._template.lookup[param])
             for jset_id in jset_ids:
                 if jset_id is not None:
                     jset[jset_id] = value
@@ -687,10 +687,11 @@ class RunConfig:
                 else:
                     extras = jset.sanco_extras
 
+                active = extras[field].active
                 if self._template.lookup[param]['dimension'] == 'scalar':
-                    extras[field] = jetto_tools.jset.ExtraNamelistItem(value, None)
+                    extras[field] = jetto_tools.jset.ExtraNamelistItem(value, None, active=active)
                 else:
-                    extras[field] = jetto_tools.jset.ExtraNamelistItem(value, 1)
+                    extras[field] = jetto_tools.jset.ExtraNamelistItem(value, 1, active=active)
 
         with open(jset_path, 'w') as f:
             f.write(str(jset))
@@ -737,7 +738,15 @@ class RunConfig:
 
             namelist_id, field = self._template.lookup[param]['nml_id']['namelist'], \
                                  self._template.lookup[param]['nml_id']['field']
-            if namelist.exists(namelist_id, field):
+
+            if field in self._template.jset.extras:
+                active = self._template.jset.extras[field].active
+            elif field in self._template.jset.sanco_extras:
+                active = self._template.jset.sanco_extras[field].active
+            else:
+                active = True
+
+            if active in (None, True) and namelist.exists(namelist_id, field):
                 if self._template.lookup[param]['dimension'] == 'vector':
                     namelist.set_array(namelist_id, field, value)
                 else:
