@@ -83,6 +83,8 @@ class JobManager:
         """
         jetto_source_dir = JobManager._find_jetto_source_dir(config)
         runs_home = os.path.join(JobManager._get_run_root(), rundir)
+        if os.path.exists(runs_home):
+            raise RuntimeError(runs_home + 'exists.  Cannot overwrite')	
 
         pointdirs = config.export(runs_home, rundir)
         for pointdir in pointdirs:
@@ -123,9 +125,12 @@ class JobManager:
         client = prominence.client.ProminenceClient(authenticated=True)
 
         runpath = os.path.join(JobManager._get_run_root(), rundir)
+        if os.path.exists(runpath):
+            raise RuntimeError(runpath + 'exists.  Cannot overwrite')
+
         pointdirs = config.export(runpath, rundir)
 
-        tarball_path = JobManager._prom_create_tarball(runpath, rundir)
+        tarball_path = JobManager._prom_create_tarball(runpath, rundir, config._npoints())
         JobManager._prom_upload_tarball(tarball_path, client)
 
         if config._npoints() == 1:
@@ -162,14 +167,15 @@ class JobManager:
         try:
             client = docker.from_env()
             container = client.containers.run(image, 
-                                              command=f"rjettov -S -I -p -xmpi -x64 -n2 prom build docker",
+                                              command=f"rjettov -I -xmpi -x64 prom build docker",
                                               volumes={rundir:{'bind': "/jetto/runs/prom", 'mode':'rw'}, 
                                                        **extra_volumes},
                                               working_dir="/jetto/runs/prom",
                                               detach = True,
-                                              auto_remove = True
+                                              auto_remove = True,
+                                              environment={'JINTRAC_IMAS_BACKEND':os.environ.get('JINTRAC_IMAS_BACKEND')}
                                               )
-        except Error as exc:
+        except Exception as exc:
             raise JobManagerError("error in docker") from exc
 
         with open(runpath/'docker.name', 'w') as f:
@@ -368,7 +374,7 @@ class JobManager:
         return completed_process.stdout.strip()
 
     @classmethod
-    def _prom_create_tarball(cls, runpath: str, rundir: str) -> str:
+    def _prom_create_tarball(cls, runpath: str, rundir: str, numpoints: int) -> str:
         """Create a tarball out of the run directory contents
 
         Creates the tarball under /tmp. File name is <rundir>-<uuid>.tgz, where rundir has any forward slash
@@ -376,8 +382,9 @@ class JobManager:
         directory was set to ``foo/bar``, then the tarball root contains the contents of the ``bar`` directory.
         Returns the full path to the created tarball.
 
-        When adding files to the tarball, the JSET files (``jetto.jset``) are excluded, as they aren't used by JETTO
-        at runtime, and they would add significantly to the size of the generated tarball.
+        When adding files to the tarball, the JSET files (``jetto.jset``) are excluded, for large scans > 500 
+        as they usually aren't used by JETTO at runtime, and they would add significantly to the size of the generated tarball.
+	See issue #31
 
         :param runpath: Full path to the run directory
         :type runpath: str
@@ -386,8 +393,12 @@ class JobManager:
         :return: Path to the tarball
         :rtype: str
         """
+
+        if (numpoints > 500):
+            print('jetto.jset exluded from upload for large scans > 500.  May cause issues for QLKNN, EBW and IMAS runs')
+
         def _filter(tarinfo):
-            if tarinfo.name.endswith('jetto.jset'):
+            if tarinfo.name.endswith('jetto.jset') and (numpoints > 500):
                 return None
             else:
                 return tarinfo
@@ -538,8 +549,22 @@ class JobManager:
                         {
                             'name': 'workdir',
                             'values': [f'prom/{os.path.basename(path)}' for path in pointdirs]
+                        },
+                        {
+                            'name': 'pointdir',
+                            'values': [f'{os.path.basename(path)}' for path in pointdirs]
                         }
-                    ]
+                    ],
+                    'notifications': [
+                        {
+                            'event': 'jobFinished', 'type': 'email'
+                        }
+                    ],
+                    'policies': {
+                        'maximumTimeInQueue': 7 * 24 * 60,
+                        'leaveInQueue': True,
+                        'autoScalingType': None
+                     }
                 }
             ]
         }
@@ -585,6 +610,11 @@ class JobManager:
         :return: Job description
         :rtype: Dict
         """
+        if workflow:
+             outdir = os.path.basename(rundir) + '/$pointdir'
+        else:
+             outdir = os.path.basename(rundir)
+
         return {
             'name': cls._prom_name(rundir),
             'tasks': cls._prom_task_description(config, factory=workflow),
@@ -601,12 +631,7 @@ class JobManager:
                 'codeid': 'jetto'
             },
             'outputDirs': [
-                os.path.basename(rundir)
-            ],
-            'notifications': [
-                {
-                    'event': 'jobFinished', 'type': 'email'
-                }
+                outdir
             ],
             'policies': {
                 'maximumTimeInQueue': 7 * 24 * 60,
@@ -895,7 +920,11 @@ def prominence_download_scan_results(workflow_id: int, outdir: str, verbose: boo
             proc = subprocess.run(['prominence',  'download',  f'{job["id"]}'], cwd=tempdir, capture_output=True)
             if proc.returncode != 0:
                 if verbose:
-                    print(f'Download of {point_dir} - failed')
+                    print(f'Download of {point_dir} - failed')   
+            proc = subprocess.run(['prominence',  'remove',  f'{job["id"]}'], cwd=tempdir, capture_output=True)
+            if proc.returncode != 0:
+                if verbose:
+                    print(f'Removal of {point_dir} - failed')
 
             os.chdir(tempdir)
             tarfile_name = f"{root}.tgz"
