@@ -366,6 +366,10 @@ class Namelist:
         if not self.exists(namelist, field):
             raise NamelistError(f'Namelist, field pair "{namelist}, {field}" not found in namelist file')
 
+        if type(value) == str:
+            self._namelists[namelist][field] = value
+            return
+
         try:
             _ = iter(self._namelists[namelist][field])
         except TypeError:
