@@ -593,9 +593,9 @@ class JettoResults:
 
     def load_eqdsk(self, time: Optional[float] = None) -> EqdskFile:
         if time is None:
-            path = self.root / 'jetto.eqdsk'
+            path = self.root / 'jetto.eqdsk_out'
         else:
-            path = self.root / f'jetto_{time:.6f}.eqdsk'
+            path = self.root / f'jetto_{time:.6f}.eqdsk_out'
 
         return EqdskFile.load(path)
 
@@ -954,4 +954,4 @@ def label_scan(scandir, template: str = None, scan_label: str = None):
     for pointdir in glob.glob(os.path.join(scandir, 'point_*')):
         point_index = int(pointdir[-3:])
         label_point(pointdir, template=template, point_index=point_index,
-                    scan_params=scan_params, scan_label=scan_label)
\ No newline at end of file
+                    scan_params=scan_params, scan_label=scan_label)
