@@ -4,7 +4,7 @@
 # These functions read and manipulate the output netCDF file of a TRANSP run.
 
 import os
-import pwd
+from getpass import getuser
 import re
 import datetime
 from collections import OrderedDict
@@ -788,7 +788,7 @@ def convert_jsp_jst_to_netcdf(machine_name, shot_no, seq_no, jsp_file, jst_file)
         seq_str = str(min(99,max(0,int(seq_no)))).zfill(2)
         shot_str = re.sub('[^0-9]','',repr(shot_no))
 
-        buid = pwd.getpwuid(os.getuid())[0]
+        buid = getuser()
         trg_dir = Path('/home/'+buid+'/cmg/catalog_transp/'+machine_name+'/'+shot_str+'/J'+seq_str+'P')
         ln_file = trg_dir / ('J'+seq_str+'P.CDF')
         if not trg_dir.exists():
