@@ -86,7 +86,7 @@ def run_root(runs_home):
 
 @pytest.fixture()
 def rundir(run_root):
-    run_root.mkdir('runtestdata')
+    #run_root.mkdir('runtestdata')
 
     return 'runtestdata'
 
@@ -386,11 +386,11 @@ class TestSubmitToBatch:
             assert actual_contents == expected_contents
 
     def test_no_error_if_utils_script_does_not_exist(self,  manager, mock_config, jintrac_env,
-                                                     processes, run_root, jetto_sources,
+                                                     processes, rundir, jetto_sources,
                                                      jetto_utils_script):
         jetto_utils_script.remove()
 
-        manager.submit_job_to_batch(mock_config, run_root.strpath)
+        manager.submit_job_to_batch(mock_config, rundir)
 
     def test_creates_jetto_utils_script_in_run_directory(self, manager, mock_config, jintrac_env,
                                                          rundir, processes, run_root, jetto_sources):
@@ -682,15 +682,15 @@ class TestSubmitSingleRunToProminence:
 
         assert self.compare_dirs(os.path.join(run_root.strpath, rundir), os.path.join(tar_extract_dir.strpath, rundir))
 
-    def test_jset_excluded_from_tarball(self, mock_prominence, manager, mock_config, jintrac_env,
-                                        run_root, rundir, tar_extract_dir, mock_prominence_client):
+    def test_jset_not_excluded_from_tarball(self, mock_prominence, manager, mock_config, jintrac_env,
+                                            run_root, rundir, tar_extract_dir, mock_prominence_client):
         manager.submit_job_to_prominence(mock_config, rundir)
 
         tarball_path = mock_prominence_client.upload.call_args[0][1]
         with tarfile.open(tarball_path) as tarball:
             tarball.extractall(path=tar_extract_dir.strpath)
 
-        assert all('jetto.jset' not in files for _1, _2, files in
+        assert any('jetto.jset' in files for _1, _2, files in
                    os.walk(os.path.join(tar_extract_dir.strpath, rundir)))
 
     @pytest.mark.parametrize('side_effect', [ConnectionError,
@@ -881,14 +881,6 @@ class TestSubmitSingleRunToProminence:
 
         assert job_['outputDirs'] == [rundir]
 
-    def test_job_notifications_has_expected_value(self, mock_prominence, manager, mock_config, jintrac_env,
-                                                  run_root, rundir, mock_prominence_client):
-        manager.submit_job_to_prominence(mock_config, rundir)
-
-        job_ = mock_prominence_client.create_job.call_args[0][0]
-
-        assert job_['notifications'] == [{'event': 'jobFinished', 'type': 'email'}]
-
     def test_job_policies_has_expected_value(self, mock_prominence, manager, mock_config, jintrac_env,
                                              run_root, rundir, mock_prominence_client):
         manager.submit_job_to_prominence(mock_config, rundir)
@@ -1026,6 +1018,8 @@ class TestSubmitScanToProminence:
                                       os.path.join(tar_extract_dir.strpath, 'bar'),
                                       ignore=['remote.jobid', 'jetto.jset'])
 
+    # No longer a useful test as JSET files are only excluded if the scan is larger than a certain limit
+    @pytest.mark.skip
     def test_jset_files_excluded_from_tarball(self, mock_prominence, manager, mock_scan_config, jintrac_env,
                                               run_root, rundir, tar_extract_dir, mock_prominence_client):
         manager.submit_job_to_prominence(mock_scan_config, rundir)
@@ -1231,7 +1225,7 @@ class TestSubmitScanToProminence:
 
         job_ = mock_prominence_client.create_workflow.call_args[0][0]['jobs'][0]
 
-        assert job_['outputDirs'] == [rundir]
+        assert job_['outputDirs'] == [rundir + '/$pointdir']
 
     def test_job_output_dirs_for_nested_rundir(self, mock_prominence, manager, mock_scan_config, jintrac_env,
                                                run_root, mock_prominence_client):
@@ -1239,15 +1233,7 @@ class TestSubmitScanToProminence:
 
         job_ = mock_prominence_client.create_workflow.call_args[0][0]['jobs'][0]
 
-        assert job_['outputDirs'] == ['bar']
-
-    def test_job_notifications_has_expected_value(self, mock_prominence, manager, mock_scan_config, jintrac_env,
-                                                  run_root, rundir, mock_prominence_client):
-        manager.submit_job_to_prominence(mock_scan_config, rundir)
-
-        job_ = mock_prominence_client.create_workflow.call_args[0][0]['jobs'][0]
-
-        assert job_['notifications'] == [{'event': 'jobFinished', 'type': 'email'}]
+        assert job_['outputDirs'] == ['bar' + '/$pointdir']
 
     def test_job_policies_has_expected_value(self, mock_prominence, manager, mock_scan_config, jintrac_env,
                                              run_root, rundir, mock_prominence_client):
@@ -1281,13 +1267,13 @@ class TestSubmitScanToProminence:
 
         assert factory['type'] == 'zip'
 
-    def test_workflow_factory_has_single_parameter(self, mock_prominence, manager, mock_scan_config, jintrac_env,
+    def test_workflow_factory_has_two_parameters(self, mock_prominence, manager, mock_scan_config, jintrac_env,
                                                    run_root, rundir, mock_prominence_client):
         manager.submit_job_to_prominence(mock_scan_config, rundir)
 
         parameters = mock_prominence_client.create_workflow.call_args[0][0]['factories'][0]['parameters']
 
-        assert len(parameters) == 1
+        assert len(parameters) == 2
 
     def test_workflow_factory_name_is_same_as_workflow(self, mock_prominence, manager, mock_scan_config, jintrac_env,
                                                        run_root, rundir, mock_prominence_client):
@@ -1307,17 +1293,17 @@ class TestSubmitScanToProminence:
 
         assert factory['jobs'] == [workflow['jobs'][0]['name']]
 
-    def test_workflow_factory_parameter_name_is_workdir(self, mock_prominence, manager, mock_scan_config, jintrac_env,
-                                                        run_root, rundir, mock_prominence_client):
+    def test_workflow_factory_workdir_parameter_name(self, mock_prominence, manager, mock_scan_config, jintrac_env,
+                                                     run_root, rundir, mock_prominence_client):
         manager.submit_job_to_prominence(mock_scan_config, rundir)
 
         parameter = mock_prominence_client.create_workflow.call_args[0][0]['factories'][0]['parameters'][0]
 
         assert parameter['name'] == 'workdir'
 
-    def test_workflow_factory_parameter_values_are_point_dirs(self, mock_prominence, manager, mock_scan_config,
-                                                              jintrac_env, run_root, rundir, mock_prominence_client,
-                                                              mock_export):
+    def test_workflow_factory_workdir_parameter_values(self, mock_prominence, manager, mock_scan_config,
+                                                       jintrac_env, run_root, rundir, mock_prominence_client,
+                                                       mock_export):
         manager.submit_job_to_prominence(mock_scan_config, rundir)
 
         expected_values = [os.path.join('prom', os.path.basename(path)) for path in mock_export(None, rundir)]
@@ -1325,6 +1311,33 @@ class TestSubmitScanToProminence:
 
         assert parameter['values'] == expected_values
 
+    def test_workflow_factory_pointdir_parameter_name(self, mock_prominence, manager, mock_scan_config, jintrac_env,
+                                                      run_root, rundir, mock_prominence_client):
+        manager.submit_job_to_prominence(mock_scan_config, rundir)
+
+        parameter = mock_prominence_client.create_workflow.call_args[0][0]['factories'][0]['parameters'][1]
+
+        assert parameter['name'] == 'pointdir'
+
+    def test_workflow_factory_pointdir_parameter_values(self, mock_prominence, manager, mock_scan_config,
+                                                        jintrac_env, run_root, rundir, mock_prominence_client,
+                                                        mock_export):
+        manager.submit_job_to_prominence(mock_scan_config, rundir)
+
+        expected_values = [os.path.basename(path) for path in mock_export(None, rundir)]
+        parameter = mock_prominence_client.create_workflow.call_args[0][0]['factories'][0]['parameters'][1]
+
+        assert parameter['values'] == expected_values
+
+    def test_workflow_factory_notifications_have_expected_value(self, mock_prominence, manager, mock_scan_config,
+                                                                jintrac_env, run_root, rundir, mock_prominence_client,
+                                                                mock_export):
+        manager.submit_job_to_prominence(mock_scan_config, rundir)
+
+        notifications = mock_prominence_client.create_workflow.call_args[0][0]['factories'][0]['notifications']
+
+        assert notifications == [{'event': 'jobFinished', 'type': 'email'}]
+
     def test_prominence_workflow_id_is_returned(self, mock_prominence, manager, mock_scan_config, jintrac_env,
                                                 run_root, rundir, mock_prominence_client):
         mock_prominence_client.create_workflow.return_value = 1234
